************
astrowidgets
************

``astrowidgets`` aims to be a set of astronomy widgets for Jupyter Lab
or Notebook, leveraging the Astropy ecosystem.

.. note::

    ``astrowidgets`` is currently in very early development.
    There may be significant changes in the API, though we will do
    our best to follow semantic versioning.

    Please let us know what would make the tool easier to use on our
    `GitHub issue tracker`_.

Getting started
===============

.. toctree::
    :maxdepth: 1

    install
    astrowidgets/index


Reference/API
=============

.. automodapi:: astrowidgets
    :no-main-docstr:
    :no-inheritance-diagram:

.. _GitHub issue tracker: https://github.com/astropy/astrowidgets/issues
